@@ -27,19 +27,21 @@ G_BEGIN_DECLS;
 typedef struct _ThunarChooserDialogClass ThunarChooserDialogClass;
 typedef struct _ThunarChooserDialog      ThunarChooserDialog;
 
-#define THUNAR_TYPE_CHOOSER_DIALOG            (thunar_chooser_dialog_get_type ())
-#define THUNAR_CHOOSER_DIALOG(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), THUNAR_TYPE_CHOOSER_DIALOG, ThunarChooserDialog))
-#define THUNAR_CHOOSER_DIALOG_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), THUNAR_TYPE_CHOOSER_DIALOG, ThunarChooserDialogClass))
-#define THUNAR_IS_CHOOSER_DIALOG(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), THUNAR_TYPE_CHOOSER_DIALOG))
+#define THUNAR_TYPE_CHOOSER_DIALOG (thunar_chooser_dialog_get_type ())
+#define THUNAR_CHOOSER_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), THUNAR_TYPE_CHOOSER_DIALOG, ThunarChooserDialog))
+#define THUNAR_CHOOSER_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), THUNAR_TYPE_CHOOSER_DIALOG, ThunarChooserDialogClass))
+#define THUNAR_IS_CHOOSER_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), THUNAR_TYPE_CHOOSER_DIALOG))
 #define THUNAR_IS_CHOOSER_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), THUNAR_TYPE_CHOOSER_DIALOG))
-#define THUNAR_CHOOSER_DIALOG_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), THUNAR_TYPE_CHOOSER_DIALOG, ThunarChooserDialogClass))
+#define THUNAR_CHOOSER_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), THUNAR_TYPE_CHOOSER_DIALOG, ThunarChooserDialogClass))
 
-GType       thunar_chooser_dialog_get_type  (void) G_GNUC_CONST;
+GType
+thunar_chooser_dialog_get_type (void) G_GNUC_CONST;
 
-void        thunar_show_chooser_dialog      (gpointer             parent,
-                                             ThunarFile          *file,
-                                             gboolean             open,
-                                             gboolean             preselect_default_checkbox);
+void
+thunar_show_chooser_dialog (gpointer    parent,
+                            ThunarFile *file,
+                            gboolean    open,
+                            gboolean    preselect_default_checkbox);
 
 G_END_DECLS;
 
