@@ -21,43 +21,63 @@
 #include "config.h"
 #endif
 
-#include <exo/exo.h>
-
-#include <libxfce4ui/libxfce4ui.h>
-
 #include "thunar/thunar-abstract-dialog.h"
-#include "thunar/thunar-toolbar-editor.h"
+#include "thunar/thunar-application.h"
 #include "thunar/thunar-dialogs.h"
 #include "thunar/thunar-gtk-extensions.h"
 #include "thunar/thunar-pango-extensions.h"
 #include "thunar/thunar-preferences.h"
 #include "thunar/thunar-private.h"
-#include "thunar/thunar-application.h"
+#include "thunar/thunar-toolbar-editor.h"
+
+#include <exo/exo.h>
+#include <libxfce4ui/libxfce4ui.h>
 
 
 
-static void     thunar_toolbar_editor_finalize                           (GObject                  *object);
-static gboolean thunar_toolbar_editor_visible_func                       (GtkTreeModel             *model,
-                                                                          GtkTreeIter              *iter,
-                                                                          gpointer                  data);
-static void     thunar_toolbar_editor_help_clicked                       (ThunarToolbarEditor      *toolbar_editor,
-                                                                          GtkWidget                *button);
-static void     thunar_toolbar_editor_swap_toolbar_items_for_all_windows (GtkListStore             *model,
-                                                                          GtkTreeIter              *item1,
-                                                                          GtkTreeIter              *item2);
-static void     thunar_toolbar_editor_move_down                          (ThunarToolbarEditor      *toolbar_editor,
-                                                                          GtkWidget                *button);
-static void     thunar_toolbar_editor_move_up                            (ThunarToolbarEditor      *toolbar_editor,
-                                                                          GtkWidget                *button);
-static void     thunar_toolbar_editor_toggle_visibility                  (ThunarToolbarEditor      *toolbar_editor,
-                                                                          const gchar              *path_string,
-                                                                          GtkCellRendererToggle    *cell_renderer);
-static void     thunar_toolbar_editor_update_buttons                     (ThunarToolbarEditor      *toolbar_editor);
-static void     thunar_toolbar_editor_use_defaults                       (ThunarToolbarEditor      *toolbar_editor,
-                                                                          GtkWidget                *button);
-static void     thunar_toolbar_editor_toggle_symbolic_icons              (ThunarToolbarEditor      *toolbar_editor);
-static void     thunar_toolbar_editor_save_model                         (ThunarToolbarEditor      *toolbar_editor);
-static void     thunar_toolbar_editor_populate_model                     (ThunarToolbarEditor      *toolbar_editor);
+enum
+{
+  COL_ID,
+  COL_VISIBILITY,
+  COL_CHECKBOX_VISIBLE,
+  COL_ICON,
+  COL_LABEL,
+  COL_TOOLTIP,
+  N_COLS
+};
+
+
+
+static void
+thunar_toolbar_editor_finalize (GObject *object);
+static void
+thunar_toolbar_editor_help_clicked (ThunarToolbarEditor *toolbar_editor,
+                                    GtkWidget           *button);
+static void
+thunar_toolbar_editor_swap_toolbar_items_for_all_windows (ThunarToolbarEditor *editor,
+                                                          GtkTreeIter         *item1,
+                                                          GtkTreeIter         *item2);
+static void
+thunar_toolbar_editor_move_down (ThunarToolbarEditor *toolbar_editor,
+                                 GtkWidget           *button);
+static void
+thunar_toolbar_editor_move_up (ThunarToolbarEditor *toolbar_editor,
+                               GtkWidget           *button);
+static void
+thunar_toolbar_editor_toggle_visibility (ThunarToolbarEditor   *toolbar_editor,
+                                         const gchar           *path_string,
+                                         GtkCellRendererToggle *cell_renderer);
+static void
+thunar_toolbar_editor_update_buttons (ThunarToolbarEditor *toolbar_editor);
+static void
+thunar_toolbar_editor_use_defaults (ThunarToolbarEditor *toolbar_editor,
+                                    GtkWidget           *button);
+static void
+thunar_toolbar_editor_toggle_symbolic_icons (ThunarToolbarEditor *toolbar_editor);
+static void
+thunar_toolbar_editor_save_model (ThunarToolbarEditor *toolbar_editor);
+static void
+thunar_toolbar_editor_populate_model (ThunarToolbarEditor *toolbar_editor);
 
 
 
@@ -72,15 +92,14 @@ struct _ThunarToolbarEditor
 
   ThunarPreferences *preferences;
 
-  GtkListStore      *model;
-  GtkTreeModel      *filter;
+  GtkListStore *model;
 
   /* Used to get information about the toolbar items, it is used as a reference. All the toolbars are changed, not just this one. */
-  GtkWidget         *toolbar;
+  GtkWidget *toolbar;
 
-  GtkWidget         *tree_view;
-  GtkWidget         *up_button;
-  GtkWidget         *down_button;
+  GtkWidget *tree_view;
+  GtkWidget *up_button;
+  GtkWidget *down_button;
 };
 
 
@@ -103,25 +122,27 @@ thunar_toolbar_editor_class_init (ThunarToolbarEditorClass *klass)
 static void
 thunar_toolbar_editor_init (ThunarToolbarEditor *toolbar_editor)
 {
-  GtkCellRenderer        *renderer;
-  GtkWidget              *button;
-  GtkWidget              *image;
-  GtkWidget              *label;
-  GtkWidget              *vbox;
-  GtkWidget              *hbox;
-  GtkWidget              *vbox_buttons;
-  GtkWidget              *separator;
-  GtkWidget              *swin;
+  GtkCellRenderer *renderer;
+  GtkWidget       *button;
+  GtkWidget       *image;
+  GtkWidget       *label;
+  GtkWidget       *vbox;
+  GtkWidget       *hbox;
+  GtkWidget       *vbox_buttons;
+  GtkWidget       *separator;
+  GtkWidget       *swin;
 
   /* grab a reference on the preferences */
   toolbar_editor->preferences = thunar_preferences_get ();
 
   /* grab a reference on the shared toolbar model */
-  toolbar_editor->model = gtk_list_store_new (4,
+  toolbar_editor->model = gtk_list_store_new (N_COLS,
                                               G_TYPE_STRING,  /* action id */
                                               G_TYPE_BOOLEAN, /* visibility */
-                                              G_TYPE_STRING,  /* icon name */
-                                              G_TYPE_STRING); /* label */
+                                              G_TYPE_BOOLEAN, /* checkbox visible */
+                                              G_TYPE_STRING,  /* icon */
+                                              G_TYPE_STRING,  /* label */
+                                              G_TYPE_STRING); /* tooltip */
 
   /* setup the dialog */
   gtk_dialog_add_button (GTK_DIALOG (toolbar_editor), _("_Close"), GTK_RESPONSE_CLOSE);
@@ -165,16 +186,11 @@ thunar_toolbar_editor_init (ThunarToolbarEditor *toolbar_editor)
   gtk_box_pack_start (GTK_BOX (hbox), swin, TRUE, TRUE, 0);
   gtk_widget_show (swin);
 
-  /* create a filter from the shared column model */
-  toolbar_editor->filter = gtk_tree_model_filter_new (GTK_TREE_MODEL (toolbar_editor->model), NULL);
-  gtk_tree_model_filter_set_visible_func (GTK_TREE_MODEL_FILTER (toolbar_editor->filter),
-                                          (GtkTreeModelFilterVisibleFunc) thunar_toolbar_editor_visible_func,
-                                          NULL, NULL);
-
   /* create the tree view */
-  toolbar_editor->tree_view = gtk_tree_view_new_with_model (toolbar_editor->filter);
+  toolbar_editor->tree_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (toolbar_editor->model));
   gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (toolbar_editor->tree_view), FALSE);
-  gtk_tree_view_set_search_column (GTK_TREE_VIEW (toolbar_editor->tree_view), 3);
+  gtk_tree_view_set_search_column (GTK_TREE_VIEW (toolbar_editor->tree_view), COL_LABEL);
+  gtk_tree_view_set_tooltip_column (GTK_TREE_VIEW (toolbar_editor->tree_view), COL_TOOLTIP);
   gtk_container_add (GTK_CONTAINER (swin), toolbar_editor->tree_view);
   gtk_widget_show (toolbar_editor->tree_view);
 
@@ -185,7 +201,8 @@ thunar_toolbar_editor_init (ThunarToolbarEditor *toolbar_editor)
                                                -1,
                                                "Active",
                                                renderer,
-                                               "active", 1,
+                                               "active", COL_VISIBILITY,
+                                               "visible", COL_CHECKBOX_VISIBLE,
                                                NULL);
 
   /* append the icon column */
@@ -194,16 +211,16 @@ thunar_toolbar_editor_init (ThunarToolbarEditor *toolbar_editor)
                                                -1,
                                                "Icon",
                                                renderer,
-                                               "icon-name", 2,
+                                               "icon-name", COL_ICON,
                                                NULL);
 
-  /* append the name column */
+  /* append the label column */
   renderer = gtk_cell_renderer_text_new ();
   gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (toolbar_editor->tree_view),
                                                -1,
-                                               "Name",
+                                               "Label",
                                                renderer,
-                                               "text", 3,
+                                               "text", COL_LABEL,
                                                NULL);
 
   /* Create the buttons vbox container */
@@ -285,30 +302,9 @@ thunar_toolbar_editor_finalize (GObject *object)
 
 
 
-static gboolean
-thunar_toolbar_editor_visible_func (GtkTreeModel *model,
-                                    GtkTreeIter  *iter,
-                                    gpointer      data)
-{
-  gboolean  visible = TRUE;
-  gchar    *id;
-
-  gtk_tree_model_get (model, iter, 0, &id, -1);
-
-  /* Always hide THUNAR_WINDOW_ACTION_VIEW_MENUBAR */
-  if (g_strcmp0 (id, "view-menubar") == 0)
-    visible = FALSE;
-
-  g_free (id);
-
-  return visible;
-}
-
-
-
 static void
 thunar_toolbar_editor_help_clicked (ThunarToolbarEditor *toolbar_editor,
-                                    GtkWidget          *button)
+                                    GtkWidget           *button)
 {
   _thunar_return_if_fail (THUNAR_IS_TOOLBAR_EDITOR (toolbar_editor));
   _thunar_return_if_fail (GTK_IS_BUTTON (button));
@@ -323,17 +319,17 @@ thunar_toolbar_editor_help_clicked (ThunarToolbarEditor *toolbar_editor,
 
 
 static void
-thunar_toolbar_editor_swap_toolbar_items_for_all_windows (GtkListStore *model,
-                                                          GtkTreeIter  *item1,
-                                                          GtkTreeIter  *item2)
+thunar_toolbar_editor_swap_toolbar_items_for_all_windows (ThunarToolbarEditor *editor,
+                                                          GtkTreeIter         *item1,
+                                                          GtkTreeIter         *item2)
 {
   ThunarApplication *application;
   GList             *windows;
   GtkTreePath       *path1;
   GtkTreePath       *path2;
 
-  path1 = gtk_tree_model_get_path (GTK_TREE_MODEL (model), item1);
-  path2 = gtk_tree_model_get_path (GTK_TREE_MODEL (model), item2);
+  path1 = gtk_tree_model_get_path (GTK_TREE_MODEL (editor->model), item1);
+  path2 = gtk_tree_model_get_path (GTK_TREE_MODEL (editor->model), item2);
 
   application = thunar_application_get ();
   windows = thunar_application_get_windows (application);
@@ -357,11 +353,8 @@ thunar_toolbar_editor_move_down (ThunarToolbarEditor *toolbar_editor,
 {
   GtkTreeSelection *selection;
   GtkTreeModel     *model;
-  GtkTreeModel     *childModel;
   GtkTreeIter       iter1;
   GtkTreeIter       iter2;
-  GtkTreeIter       childIter1;
-  GtkTreeIter       childIter2;
 
   _thunar_return_if_fail (THUNAR_IS_TOOLBAR_EDITOR (toolbar_editor));
   _thunar_return_if_fail (GTK_IS_BUTTON (button));
@@ -373,28 +366,20 @@ thunar_toolbar_editor_move_down (ThunarToolbarEditor *toolbar_editor,
   if (gtk_tree_model_iter_next (model, &iter2) == FALSE)
     return;
 
-  /* tree view's model is made from GTK_TREE_MODEL_FILTER, hence fetching child model and child iter's */
-  gtk_tree_model_filter_convert_iter_to_child_iter (GTK_TREE_MODEL_FILTER (model), &childIter1, &iter1);
-  gtk_tree_model_filter_convert_iter_to_child_iter (GTK_TREE_MODEL_FILTER (model), &childIter2, &iter2);
-  childModel = gtk_tree_model_filter_get_model(GTK_TREE_MODEL_FILTER (model));
-
-  gtk_list_store_swap (GTK_LIST_STORE (childModel), &childIter1, &childIter2);
-  thunar_toolbar_editor_swap_toolbar_items_for_all_windows (GTK_LIST_STORE (childModel), &childIter1, &childIter2);
+  gtk_list_store_swap (GTK_LIST_STORE (model), &iter1, &iter2);
+  thunar_toolbar_editor_swap_toolbar_items_for_all_windows (toolbar_editor, &iter1, &iter2);
 }
 
 
 
 static void
 thunar_toolbar_editor_move_up (ThunarToolbarEditor *toolbar_editor,
-                               GtkWidget          *button)
+                               GtkWidget           *button)
 {
   GtkTreeSelection *selection;
   GtkTreeModel     *model;
-  GtkTreeModel     *childModel;
   GtkTreeIter       iter1;
   GtkTreeIter       iter2;
-  GtkTreeIter       childIter1;
-  GtkTreeIter       childIter2;
 
   _thunar_return_if_fail (THUNAR_IS_TOOLBAR_EDITOR (toolbar_editor));
   _thunar_return_if_fail (GTK_IS_BUTTON (button));
@@ -406,26 +391,20 @@ thunar_toolbar_editor_move_up (ThunarToolbarEditor *toolbar_editor,
   if (gtk_tree_model_iter_previous (model, &iter2) == FALSE)
     return;
 
-  /* tree view's model is made from GTK_TREE_MODEL_FILTER, hence fetching child model and child iter's */
-  gtk_tree_model_filter_convert_iter_to_child_iter (GTK_TREE_MODEL_FILTER (model), &childIter1, &iter1);
-  gtk_tree_model_filter_convert_iter_to_child_iter (GTK_TREE_MODEL_FILTER (model), &childIter2, &iter2);
-  childModel = gtk_tree_model_filter_get_model(GTK_TREE_MODEL_FILTER (model));
-
-  gtk_list_store_swap (GTK_LIST_STORE (childModel), &childIter1, &childIter2);
-  thunar_toolbar_editor_swap_toolbar_items_for_all_windows (GTK_LIST_STORE (childModel), &childIter1, &childIter2);
+  gtk_list_store_swap (GTK_LIST_STORE (model), &iter1, &iter2);
+  thunar_toolbar_editor_swap_toolbar_items_for_all_windows (toolbar_editor, &iter1, &iter2);
 }
 
 
 
 static void
-thunar_toolbar_editor_toggle_visibility (ThunarToolbarEditor    *toolbar_editor,
-                                         const gchar            *path_string,
-                                         GtkCellRendererToggle  *cell_renderer)
+thunar_toolbar_editor_toggle_visibility (ThunarToolbarEditor   *toolbar_editor,
+                                         const gchar           *path_string,
+                                         GtkCellRendererToggle *cell_renderer)
 {
   ThunarApplication *application;
   GList             *windows;
   GtkTreePath       *path;
-  GtkTreePath       *child_path;
   GtkTreeIter        iter;
   gboolean           visible;
 
@@ -435,16 +414,7 @@ thunar_toolbar_editor_toggle_visibility (ThunarToolbarEditor    *toolbar_editor,
 
   /* determine the tree path for the string */
   path = gtk_tree_path_new_from_string (path_string);
-
-  child_path = gtk_tree_model_filter_convert_path_to_child_path (GTK_TREE_MODEL_FILTER (toolbar_editor->filter), path);
-
-  if (child_path == NULL)
-    {
-      gtk_tree_path_free (path);
-      return;
-    }
-
-  if (gtk_tree_model_get_iter (GTK_TREE_MODEL (toolbar_editor->model), &iter, child_path))
+  if (gtk_tree_model_get_iter (GTK_TREE_MODEL (toolbar_editor->model), &iter, path))
     {
       gtk_tree_model_get (GTK_TREE_MODEL (toolbar_editor->model), &iter, 1, &visible, -1);
       gtk_list_store_set (toolbar_editor->model, &iter, 1, !visible, -1);
@@ -455,13 +425,12 @@ thunar_toolbar_editor_toggle_visibility (ThunarToolbarEditor    *toolbar_editor,
   for (GList *lp = windows; lp != NULL; lp = lp->next)
     {
       ThunarWindow *window = lp->data;
-      thunar_window_toolbar_toggle_item_visibility (window, gtk_tree_path_get_indices (child_path)[0]);
+      thunar_window_toolbar_toggle_item_visibility (window, gtk_tree_path_get_indices (path)[0]);
     }
   g_object_unref (application);
   g_list_free (windows);
 
   gtk_tree_path_free (path);
-  gtk_tree_path_free (child_path);
 }
 
 
@@ -507,10 +476,10 @@ thunar_toolbar_editor_use_defaults (ThunarToolbarEditor *toolbar_editor,
                                     GtkWidget           *button)
 {
   GList *toolbar_items;
-  guint item_count = gtk_tree_model_iter_n_children (GTK_TREE_MODEL (toolbar_editor->model), NULL);
-  guint target_order[item_count];
-  guint current_order[item_count];
-  guint index;
+  guint  item_count = gtk_tree_model_iter_n_children (GTK_TREE_MODEL (toolbar_editor->model), NULL);
+  guint  target_order[item_count];
+  guint  current_order[item_count];
+  guint  index;
 
   toolbar_items = gtk_container_get_children (GTK_CONTAINER (toolbar_editor->toolbar));
 
@@ -518,7 +487,7 @@ thunar_toolbar_editor_use_defaults (ThunarToolbarEditor *toolbar_editor,
   for (GList *lp = toolbar_items; lp != NULL; lp = lp->next)
     {
       GtkWidget *item = lp->data;
-      gint *order = NULL;
+      gint      *order = NULL;
 
       order = g_object_get_data (G_OBJECT (item), "default-order");
       current_order[index] = *order;
@@ -536,7 +505,7 @@ thunar_toolbar_editor_use_defaults (ThunarToolbarEditor *toolbar_editor,
           if (x == y && i != j)
             {
               GtkTreeIter iter_i, iter_j;
-              gchar *path_i, *path_j;
+              gchar      *path_i, *path_j;
 
               path_i = g_strdup_printf ("%i", i);
               path_j = g_strdup_printf ("%i", j);
@@ -545,7 +514,7 @@ thunar_toolbar_editor_use_defaults (ThunarToolbarEditor *toolbar_editor,
               gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (toolbar_editor->model), &iter_i, path_i);
               gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (toolbar_editor->model), &iter_j, path_j);
               gtk_list_store_swap (GTK_LIST_STORE (toolbar_editor->model), &iter_i, &iter_j);
-              thunar_toolbar_editor_swap_toolbar_items_for_all_windows (toolbar_editor->model, &iter_i, &iter_j);
+              thunar_toolbar_editor_swap_toolbar_items_for_all_windows (toolbar_editor, &iter_i, &iter_j);
 
               y = current_order[i];
               current_order[i] = target_order[i];
@@ -589,10 +558,10 @@ thunar_toolbar_editor_save_model (ThunarToolbarEditor *toolbar_editor)
   /* read the internal id and visibility column values and store them */
   for (guint i = 0; i < item_count; i++)
     {
-      GtkTreeIter  iter;
-      gchar       *path;
-      gchar       *id;
-      gboolean     visible;
+      GtkTreeIter iter;
+      gchar      *path;
+      gchar      *id;
+      gboolean    visible;
 
       /* get iterator for the ith item */
       path = g_strdup_printf ("%i", i);
@@ -600,7 +569,7 @@ thunar_toolbar_editor_save_model (ThunarToolbarEditor *toolbar_editor)
       g_free (path);
 
       /* get the id value of the entry */
-      gtk_tree_model_get (GTK_TREE_MODEL (toolbar_editor->model), &iter, 0, &id, -1);
+      gtk_tree_model_get (GTK_TREE_MODEL (toolbar_editor->model), &iter, COL_ID, &id, -1);
       if (id == NULL)
         continue;
 
@@ -616,7 +585,7 @@ thunar_toolbar_editor_save_model (ThunarToolbarEditor *toolbar_editor)
       g_string_append_c (items, ':');
 
       /* get the visibility value of the entry and store it */
-      gtk_tree_model_get (GTK_TREE_MODEL (toolbar_editor->model), &iter, 1, &visible, -1);
+      gtk_tree_model_get (GTK_TREE_MODEL (toolbar_editor->model), &iter, COL_VISIBILITY, &visible, -1);
       g_string_append_printf (items, "%i", visible);
     }
 
@@ -645,6 +614,8 @@ thunar_toolbar_editor_populate_model (ThunarToolbarEditor *toolbar_editor)
       gchar     *id = NULL;
       gchar     *icon = NULL;
       gchar     *label_with_mnemonic = NULL;
+      gchar     *tooltip = NULL;
+      gboolean   checkbox_visible = TRUE;
 
       id = g_object_get_data (G_OBJECT (item), "id");
       icon = g_object_get_data (G_OBJECT (item), "icon");
@@ -653,12 +624,20 @@ thunar_toolbar_editor_populate_model (ThunarToolbarEditor *toolbar_editor)
       widget = gtk_label_new_with_mnemonic (label_with_mnemonic);
       g_object_ref_sink (widget);
 
+      if (g_strcmp0 (id, "menu") == 0)
+        {
+          checkbox_visible = FALSE;
+          tooltip = _("Only visible when the menubar is hidden");
+        }
+
       gtk_list_store_append (toolbar_editor->model, &iter);
       gtk_list_store_set (toolbar_editor->model, &iter,
-                          0, id,
-                          1, gtk_widget_is_visible (item),
-                          2, icon,
-                          3, gtk_label_get_text (GTK_LABEL (widget)),
+                          COL_ID, id,
+                          COL_VISIBILITY, gtk_widget_is_visible (item),
+                          COL_CHECKBOX_VISIBLE, checkbox_visible,
+                          COL_ICON, icon,
+                          COL_LABEL, gtk_label_get_text (GTK_LABEL (widget)),
+                          COL_TOOLTIP, tooltip,
                           -1);
 
       g_object_unref (widget);
@@ -675,7 +654,7 @@ thunar_toolbar_editor_populate_model (ThunarToolbarEditor *toolbar_editor)
   g_signal_connect_swapped (G_OBJECT (selection), "changed", G_CALLBACK (thunar_toolbar_editor_update_buttons), toolbar_editor);
 
   /* select the first item */
-  if (gtk_tree_model_get_iter_first (GTK_TREE_MODEL (toolbar_editor->filter), &iter))
+  if (gtk_tree_model_get_iter_first (GTK_TREE_MODEL (toolbar_editor->model), &iter))
     gtk_tree_selection_select_iter (selection, &iter);
 
   g_list_free (toolbar_items);
